---
title: "SOC 2 Type II"
description: "Terraform compliance scanning for SOC 2 Type II — assess for free, remediate with ComplyForm"
---

import { Badge } from '@astrojs/starlight/components';

<Badge text="Community" variant="success" />
<Badge text="Audit" variant="tip" />

**Issuing body:** [AICPA](https://www.aicpa.org)
**Jurisdiction:** Global — Global
**Countries:** Worldwide


## Assessment

Assess your infrastructure against SOC 2 for free at any tier:

```bash
complyform assess --frameworks=soc2
```

## Remediation

Remediation is included free at all tiers.

```bash
complyform remediate --frameworks=soc2
```

## Related Frameworks

- [CIS GCP v2.0](/frameworks/cis_gcp)
- [CIS Azure v2.0](/frameworks/cis_azure)
- [CIS AWS v3.0](/frameworks/cis_aws)
